@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.27 2001/10/30 22:42:35 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.28 2001/11/15 23:18:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -169,21 +169,21 @@ void Form::draw_frame_modal ()
 
     GdkPixbuf *pixbuf;
 
-    pixbuf = draw_solid (width, 2);
+    pixbuf = draw_solid (width + 1, 2);
     FormEditor::draw_pixbuf (*frame_group, pixbuf, 0, -2);
-    FormEditor::draw_pixbuf (*frame_group, pixbuf, 0, height);
+    FormEditor::draw_pixbuf (*frame_group, pixbuf, 0, height + 1);
     gdk_pixbuf_unref (pixbuf);
 
-    pixbuf = draw_solid (2, height);
+    pixbuf = draw_solid (2, height + 1);
     FormEditor::draw_pixbuf (*frame_group, pixbuf, -2, 0);
-    FormEditor::draw_pixbuf (*frame_group, pixbuf, width, 0);
+    FormEditor::draw_pixbuf (*frame_group, pixbuf, width + 1, 0);
     gdk_pixbuf_unref (pixbuf);
 
     pixbuf = draw_solid (2, 2);
     FormEditor::draw_pixbuf (*frame_group, pixbuf, -1, -1);
-    FormEditor::draw_pixbuf (*frame_group, pixbuf, width -1, -1);
-    FormEditor::draw_pixbuf (*frame_group, pixbuf, width -1, height -1);
-    FormEditor::draw_pixbuf (*frame_group, pixbuf, -1, height -1);
+    FormEditor::draw_pixbuf (*frame_group, pixbuf, width, -1);
+    FormEditor::draw_pixbuf (*frame_group, pixbuf, width, height);
+    FormEditor::draw_pixbuf (*frame_group, pixbuf, -1, height);
     gdk_pixbuf_unref (pixbuf);
 }
 
