@@ -1,4 +1,4 @@
-//$Id: graffiti.h,v 1.6 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.h,v 1.7 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -40,8 +40,8 @@ namespace Guikachu
 	    GUI::FormEditor::GraffitiProperties *editor;
 	    
 	public:
-	    Graffiti (Resources::Form *owner,
-		      const string& id);
+	    Graffiti (Resources::Form   *owner,
+		      const std::string &id);
 	    virtual ~Graffiti ();
 	    
 	    virtual Type get_type () const { return WIDGET_GRAFFITI; };
@@ -53,7 +53,7 @@ namespace Guikachu
 	    // Persistance
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     }
 }
