@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.13 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.14 2001/11/11 20:56:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,7 +43,7 @@ void ListCanvasItem::update ()
 
     int font_num = widget->font;    
     int height = get_font_height (font_num) * widget->visible_items;
-    int width = widget->width;
+    int width = widget->get_display_width ();
     bool usable = widget->usable;
 
     /* Render text items */
@@ -60,18 +60,13 @@ void ListCanvasItem::update ()
     for (int i = 0; i < visible_strings; i++)
     {
 	draw_text (*group, listitems[i], font_num,
-		   text_x, text_y, usable);
+		   text_x, text_y, usable,
+		   GTK_ANCHOR_NW,
+		   width - 4);
 	text_y += line_spacing;
     }
 
     /* Render frame */
-    if (!widget->manual_width)
-    {
-	width = 18;
-	if (listitems.size ())
-	    width = get_string_width (font_num, listitems[0]) + 3;
-    }
-
     int x1 = widget->x - 1;
     int y1 = widget->y - 1;
     int x2 = x1 + width + 1;
