@@ -1,4 +1,4 @@
-//$Id: text-field.cc,v 1.4 2001/11/06 12:54:54 cactus Exp $ -*- c++ -*-
+//$Id: text-field.cc,v 1.6 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -185,15 +185,15 @@ void TextField::save_rcp (std::ostream &ostr) const
 {
     gchar *width_str, *height_str;
 
-    if (manual_width)
-	width_str = g_strdup_printf ("%d", width ());
-    else
-	width_str = g_strdup ("7");
+    width_str = g_strdup_printf ("%d", get_display_width ());
     
     if (manual_height)
 	height_str = g_strdup_printf ("%d", height ());
     else
 	height_str = g_strdup ("AUTO");
+    
+    g_free (height_str);
+    g_free (width_str);
 
     ostr << "  FIELD ID " << id;
     ostr << " AT (" << x << " " << y << " " << width_str << " " << height_str << ")";
@@ -241,17 +241,14 @@ void TextField::save_rcp (std::ostream &ostr) const
 	ostr << " HASSCROLLBAR";
 
     ostr << std::endl;
-    
-    g_free (height_str);
-    g_free (width_str);
 }
 
-int TextField::get_auto_width ()
+int TextField::get_auto_width () const
 {
     return 30;
 }
 
-int TextField::get_display_height ()
+int TextField::get_display_height () const
 {
     int min_height = get_auto_height ();
     
@@ -261,7 +258,7 @@ int TextField::get_display_height ()
     return min_height;
 }
 
-int TextField::get_auto_height ()
+int TextField::get_auto_height () const
 {
     return get_font_height (font);
 }
