@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.10 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.12 2001/11/14 15:10:36 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,6 +21,7 @@
 #include "resource-manager.h"
 #include "session.h"
 #include <gnome--/main.h>
+#include <gnome--/messagebox.h>
 
 using namespace Guikachu;
 using std::string;
@@ -45,16 +46,21 @@ bool GUI::MainWin::check_save ()
 	message = g_strdup (
 	    "The current file is unsaved.\n"
 	    "Would you like to save it?");
-    
-    Gnome::Dialog *dialog = Gnome::Dialogs::question_modal (message);
-    g_free (message);
-    
+
+    Gnome::Dialog *dialog = new Gnome::MessageBox (
+	message, GNOME_MESSAGE_BOX_QUESTION, std::vector<string>());
+    dialog->append_button (_("Save"), GNOME_STOCK_PIXMAP_SAVE);
+    dialog->append_button (_("Discard"), GNOME_STOCK_PIXMAP_TRASH);
     dialog->append_button (GNOME_STOCK_BUTTON_CANCEL);
+
+    dialog->set_modal (true);
     dialog->set_default (0);
+    gnome_dialog_grab_focus (dialog->gtkobj (), 0);
     
     response = dialog->run_and_close ();
 
-    if (response == 2) // Cancel
+    if (response == 2 ||
+	response == -1) // Cancel
 	return false;
 
     if (response == 1) // No
@@ -62,8 +68,12 @@ bool GUI::MainWin::check_save ()
 	    Gnome::Main::quit ();
     
     if (response == 0) // Yes
+    {
 	save_cb ();
-    
+	if (ResourceManager::is_dirty ())
+	    return check_save ();
+    }
+	    
     return true;
 }
 
@@ -89,6 +99,7 @@ void GUI::MainWin::set_filename (const string& filename_)
 void GUI::MainWin::filesel_close_cb (Gtk::FileSelection *fs)
 {
     delete fs;
+    Gtk::Main::quit ();
 }
 
 void GUI::MainWin::save_cb ()
@@ -118,6 +129,7 @@ void GUI::MainWin::save_as_cb ()
     fs->set_transient_for (*this);
     fs->set_modal (true);
     fs->show ();
+    Gtk::Main::run ();
 }
 
 void GUI::MainWin::load_cb ()
@@ -140,6 +152,7 @@ void GUI::MainWin::load_cb ()
     fs->set_transient_for (*this);
     fs->set_modal (true);
     fs->show ();
+    Gtk::Main::run ();
 }
 
 void GUI::MainWin::export_cb ()
