@@ -1,4 +1,4 @@
-//$Id: menu-res.h,v 1.6 2001/11/03 19:18:30 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.h,v 1.7 2001/11/06 12:54:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,38 +44,41 @@ namespace Guikachu
     {
 	struct MenuItem
 	{
-	    bool separator;
-	    string id;
-	    string label;
-	    char shortcut;
+	    bool        separator;
+	    std::string id;
+	    std::string label;
+	    char        shortcut;
 	};
 
 	struct Submenu
 	{
-	    string label;
-	    vector<MenuItem> items;
+	    std::string           label;
+	    std::vector<MenuItem> items;
+
 	    Submenu () {};
-	    Submenu (const string& label_): label (label_) {};
+	    Submenu (const std::string& label_): label (label_) {};
 	};
 	
 	class Menu: public Resource
 	{
+	    typedef std::vector<Submenu> MenuTree;
+	    
 	    Guikachu::GUI::MenuWindow *gui;
-	    vector<Submenu> submenus;
+	    MenuTree submenus;
 	public:
-	    Menu (const string& id);
+	    Menu (const std::string& id);
 	    virtual ~Menu ();
 	    
 	    virtual Type get_type () const { return RESOURCE_MENU; };
 	    virtual void show_ui ();
 
-	    vector<Submenu> get_submenus () const { return submenus; };
-	    void set_submenus (const vector<Submenu>& submenus);
+	    MenuTree get_submenus () const { return submenus; };
+	    void     set_submenus (const MenuTree& submenus);
 	    
 	private:
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
-	    virtual void save_rcp (ostream &ostr) const;
+	    virtual void save_rcp (std::ostream &ostr) const;
 	};
     };
 };
