@@ -1,4 +1,4 @@
-//$Id: menu-win.cc,v 1.17 2001/11/06 17:04:30 cactus Exp $ -*- c++ -*-
+//$Id: menu-win.cc,v 1.18 2001/11/18 10:59:50 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -36,7 +36,7 @@ GUI::MenuWindow::MenuWindow (Guikachu::Resources::Menu *res_):
     res (res_),
     update_block (false)
 {
-    gui = glade_xml_new (GLADEDIR "/guikachu.glade", NULL);
+    gui = glade_xml_new (GLADEDIR "/guikachu.glade", "res_menu");
 
     using Gtk::wrap;
     using namespace SigC;
